"""数据模型."""

from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field


class SMSMessage(BaseModel):
    """短信消息模型."""
    sender: Optional[str] = Field(default="未知发送者", description="发送者手机号或名称")
    content: str = Field(..., description="短信内容")
    timestamp: Optional[datetime] = Field(default_factory=datetime.now, description="接收时间")


class NotificationRequest(BaseModel):
    """通知请求模型."""
    api_key: str = Field(..., description="API 密钥")
    message: SMSMessage = Field(..., description="短信消息")


class SimpleNotificationRequest(BaseModel):
    """简化的通知请求模型 - 只需要内容."""
    api_key: str = Field(..., description="API 密钥")
    content: str = Field(..., description="短信内容")
    sender: Optional[str] = Field(default=None, description="发送者（可选）")


class NotificationResponse(BaseModel):
    """通知响应模型."""
    success: bool = Field(..., description="是否成功")
    message: str = Field(..., description="响应消息")
    timestamp: datetime = Field(default_factory=datetime.now, description="响应时间")


class SystemStatus(BaseModel):
    """系统状态模型."""
    version: str
    uptime: float
    notifications_sent: int
    notifications_failed: int
